@@ -1,15 +1,9 @@
 import os
 import platform
-import shutil
-from distutils.dir_util import copy_tree
-
-
-import click
+from shutil import copytree
 
 from pick import pick
 
-from ftrack_ams.functions import get_yes_no
-
 proj_dir_windows = "X:"
 proj_dir_macos = "/Volumes/ams-fileserver/"
 
@@ -64,9 +58,11 @@ def create_project_on_fileserver(project, internal=False, deal=None):
         project_dir
     ) else os.makedirs(project_dir)
     project_go = os.path.join(project_dir, go_folder)
-    print(f"{project_go} already exists") if os.path.isdir(project_go) else os.makedirs(project_go)
+    print(f"{project_go} already exists") if os.path.isdir(
+        project_go) else os.makedirs(project_go)
     project_mv = os.path.join(project_dir, mv_folder)
-    print(f"{project_mv} already exists") if os.path.isdir(project_mv) else os.makedirs(project_mv)
+    print(f"{project_mv} already exists") if os.path.isdir(
+        project_mv) else os.makedirs(project_mv)
 
     if deal is not None:
         deal_dir = os.path.join(dir, deal_folder, deal)
@@ -74,10 +70,10 @@ def create_project_on_fileserver(project, internal=False, deal=None):
         deal_mv = os.path.join(deal_dir, "MV")
 
         if os.path.isdir(deal_go):
-            copy_tree(deal_go, project_go)
+            copytree(deal_go, project_go)
 
         if os.path.isdir(deal_mv):
-            copy_tree(deal_mv, project_mv)
+            copytree(deal_mv, project_mv)
         else:
             print("probber on MV proj")
 
@@ -85,4 +81,5 @@ def create_project_on_fileserver(project, internal=False, deal=None):
         maps = os.path.join(project_dir, "Maps")
         print(f"{maps} already exists") if os.path.isdir(maps) else os.makedirs(maps)
         scenes = os.path.join(project_dir, "Scenes")
-        print(f"{scenes} already exists") if os.path.isdir(scenes) else os.makedirs(scenes)
+        print(f"{scenes} already exists") if os.path.isdir(
+            scenes) else os.makedirs(scenes)
